.. Mypy documentation master file, created by
   sphinx-quickstart on Sun Sep 14 19:50:35 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mypy documentation!
==============================

Mypy is a static type checker for Python 3 and Python 2.7.

.. toctree::
   :maxdepth: 2
   :caption: First steps

   introduction
   getting_started
   existing_code

.. toctree::
   :maxdepth: 2
   :caption: Cheat sheets

   cheat_sheet_py3
   cheat_sheet

.. toctree::
   :maxdepth: 2
   :caption: Type system reference

   builtin_types
   type_inference_and_annotations
   kinds_of_types
   class_basics
   protocols
   python2
   dynamic_typing
   casts
   duck_type_compatibility
   stubs
   generics
   more_types
   metaclasses

.. toctree::
   :maxdepth: 2
   :caption: Configuring and running mypy

   running_mypy
   command_line
   config_file
   mypy_daemon
   installed_packages
   extending_mypy

.. toctree::
   :maxdepth: 2
   :caption: Miscellaneous

   common_issues
   supported_python_features
   python36
   additional_features
   faq
   revision_history

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
